@@ -111,11 +111,6 @@ const ExpectedCRDs = 7
 // camel-k-operator-knative
 const ExpectedKubePromoteRoles = 7
 
-// camel-k-edit
-// camel-k-operator-custom-resource-definitions
-// camel-k-operator-bind-addressable-resolver
-const ExpectedKubeClusterRoles = 3
-
 // camel-k-operator-openshift
 const ExpectedOSPromoteRoles = 1
 
@@ -520,7 +515,7 @@ func StructuredLogs(t *testing.T, ctx context.Context, ns, podName string, optio
 				continue
 			} else {
 				msg := fmt.Sprintf("Unable to parse structured content: %s", t)
-				log.Errorf(err, msg)
+				log.Error(err, msg)
 				return nil, fmt.Errorf("%s %w\n", msg, err)
 			}
 		}
@@ -2160,16 +2155,6 @@ func SelectedPlatformPhase(t *testing.T, ctx context.Context, ns string, name st
 	}
 }
 
-func SelectedIntegrationProfilePhase(t *testing.T, ctx context.Context, ns string, name string) func() v1.IntegrationProfilePhase {
-	return func() v1.IntegrationProfilePhase {
-		pc := IntegrationProfileByName(t, ctx, ns, name)()
-		if pc == nil {
-			return ""
-		}
-		return pc.Status.Phase
-	}
-}
-
 func PlatformHas(t *testing.T, ctx context.Context, ns string, predicate func(pl *v1.IntegrationPlatform) bool) func() bool {
 	return func() bool {
 		pl := Platform(t, ctx, ns)()
