@@ -17,7 +17,7 @@ limitations under the License.
 
 package apis
 
-import "github.com/apache/camel-k/pkg/util/openshift"
+import "github.com/apache/camel-k/v2/pkg/util/openshift"
 
 func init() {
 	// Register the types with the Scheme so the components can map objects to GroupVersionKinds and back
