@@ -72,7 +72,7 @@ func TestTraitsMerge(t *testing.T) {
 	assert.NotNil(t, t1.Container)
 	assert.False(t, ptr.Deref(t1.Container.Auto, true))
 	assert.Equal(t, "http-8081", t1.Container.PortName)
-	assert.Equal(t, 81, t1.Container.ServicePort)
+	assert.Equal(t, int32(81), t1.Container.ServicePort)
 
 	// values from merged trait take precedence over the original ones
 	assert.NotNil(t, t1.Logging)
@@ -162,7 +162,7 @@ func TestIntegrationKitTraitsMerge(t *testing.T) {
 }
 
 func TestDecodeValueSourceValid(t *testing.T) {
-	res, err := DecodeValueSource("configmap:my-configmap", "defaultkey", "errorMessage")
+	res, err := DecodeValueSource("configmap:my-configmap", "defaultkey")
 	require.NoError(t, err)
 
 	assert.NotNil(t, res)
@@ -170,7 +170,7 @@ func TestDecodeValueSourceValid(t *testing.T) {
 	assert.NotNil(t, res.ConfigMapKeyRef)
 	assert.Equal(t, "defaultkey", res.ConfigMapKeyRef.Key)
 
-	res, err = DecodeValueSource("configmap:my-configmap/my-key", "defaultkey", "errorMessage")
+	res, err = DecodeValueSource("configmap:my-configmap/my-key", "defaultkey")
 	require.NoError(t, err)
 
 	assert.NotNil(t, res)
@@ -178,7 +178,7 @@ func TestDecodeValueSourceValid(t *testing.T) {
 	assert.NotNil(t, res.ConfigMapKeyRef)
 	assert.Equal(t, "my-key", res.ConfigMapKeyRef.Key)
 
-	res, err = DecodeValueSource("secret:my-secret/mykey", "defaultkey", "errorMessage")
+	res, err = DecodeValueSource("secret:my-secret/mykey", "defaultkey")
 	require.NoError(t, err)
 
 	assert.NotNil(t, res)
@@ -186,7 +186,7 @@ func TestDecodeValueSourceValid(t *testing.T) {
 	assert.NotNil(t, res.SecretKeyRef)
 	assert.Equal(t, "mykey", res.SecretKeyRef.Key)
 
-	res, err = DecodeValueSource("secret:my-secret", "defaultkey", "errorMessage")
+	res, err = DecodeValueSource("secret:my-secret", "defaultkey")
 	require.NoError(t, err)
 
 	assert.NotNil(t, res)
@@ -235,10 +235,10 @@ func TestDecodeValueSourceInvalid(t *testing.T) {
 
 	for i, tc := range testcases {
 		t.Run(fmt.Sprintf("test-%d-%s", i, tc.name), func(t *testing.T) {
-			res, err := DecodeValueSource(tc.input, tc.defaultKey, tc.errorMessage)
+			res, err := DecodeValueSource(tc.input, tc.defaultKey)
 			require.Error(t, err)
 			assert.Equal(t, ValueSource{}, res)
-			assert.Equal(t, err.Error(), tc.errorMessage)
+			assert.Equal(t, err.Error(), "could not decode "+tc.input)
 		})
 	}
 
