@@ -18,30 +18,25 @@ limitations under the License.
 package builder
 
 import (
+	"context"
 	"fmt"
 	"os"
+	"path/filepath"
 	"strings"
 	"testing"
 
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/jib"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
-func TestJibBuildMavenMissingContext(t *testing.T) {
-	args, err := buildJibMavenArgs("missing-dir", "my-image", "my-base-image", true, nil)
-	require.Error(t, err)
-	assert.Nil(t, args)
-	assert.Contains(t, err.Error(), "no such file or directory")
-}
-
 func TestJibBuildMavenArgs(t *testing.T) {
 	tmpMvnCtxDir, err := os.MkdirTemp("", "my-build-test")
 	require.NoError(t, err)
-	require.NoError(t, os.WriteFile(tmpMvnCtxDir+"/MAVEN_CONTEXT", []byte(`-x some-maven-option`), 0o400))
-	args, err := buildJibMavenArgs(tmpMvnCtxDir, "my-image", "my-base-image", true, nil)
-	require.NoError(t, err)
+	args := buildJibMavenArgs(tmpMvnCtxDir, "my-image", "my-base-image", true, nil)
 	expectedParams := strings.Split(
-		fmt.Sprintf("jib:build -Djib.disableUpdateChecks=true -x some-maven-option -P jib -Djib.to.image=my-image "+
+		fmt.Sprintf("jib:build -Djib.disableUpdateChecks=true -P jib -Djib.to.image=my-image "+
 			"-Djib.from.image=my-base-image -Djib.baseImageCache=%s -Djib.container.user=1000 -Djib.allowInsecureRegistries=true", tmpMvnCtxDir+"/jib"),
 		" ")
 	assert.Equal(t, expectedParams, args)
@@ -50,13 +45,54 @@ func TestJibBuildMavenArgs(t *testing.T) {
 func TestJibBuildMavenArgsWithPlatforms(t *testing.T) {
 	tmpMvnCtxDir, err := os.MkdirTemp("", "my-build-test")
 	require.NoError(t, err)
-	require.NoError(t, os.WriteFile(tmpMvnCtxDir+"/MAVEN_CONTEXT", []byte(`-x some-maven-option`), 0o400))
-	args, err := buildJibMavenArgs(tmpMvnCtxDir, "my-image", "my-base-image", true, []string{"amd64", "arm64"})
-	require.NoError(t, err)
+	args := buildJibMavenArgs(tmpMvnCtxDir, "my-image", "my-base-image", true, []string{"amd64", "arm64"})
 	expectedParams := strings.Split(
-		fmt.Sprintf("jib:build -Djib.disableUpdateChecks=true -x some-maven-option -P jib -Djib.to.image=my-image "+
+		fmt.Sprintf("jib:build -Djib.disableUpdateChecks=true -P jib -Djib.to.image=my-image "+
 			"-Djib.from.image=my-base-image -Djib.baseImageCache=%s -Djib.container.user=1000 -Djib.from.platforms=amd64,arm64 -Djib.allowInsecureRegistries=true",
 			tmpMvnCtxDir+"/jib"),
 		" ")
 	assert.Equal(t, expectedParams, args)
 }
+
+func TestInjectJibProfileMissingPom(t *testing.T) {
+	tmpMvnCtxDir, err := os.MkdirTemp("", "ck-jib-profile-test")
+	require.NoError(t, err)
+	builderContext := builderContext{
+		C:    context.TODO(),
+		Path: tmpMvnCtxDir,
+	}
+	err = injectJibProfile(&builderContext)
+	assert.Error(t, err)
+	assert.Contains(t, err.Error(), "no such file or directory")
+}
+
+var poms = []string{
+	"<project>something</project>",
+	"<project>something<profiles><profile></profile></profiles></project>",
+	"<no-project-tag></no-project-tag>",
+}
+
+func TestInjectJibProfiles(t *testing.T) {
+	tmpMvnCtxDir, err := os.MkdirTemp("", "ck-jib-profile-test")
+	require.NoError(t, err)
+	builderContext := builderContext{
+		C:    context.TODO(),
+		Path: tmpMvnCtxDir,
+	}
+
+	for _, p := range poms {
+		pom := filepath.Join(tmpMvnCtxDir, "maven", "pom.xml")
+		err = util.WriteFileWithContent(pom, []byte(p))
+		require.NoError(t, err)
+		err = injectJibProfile(&builderContext)
+		require.NoError(t, err)
+
+		newPom, err := util.ReadFile(pom)
+		require.NoError(t, err)
+		// This case should never happen but we check if the user set a non valid pom
+		if p != "<no-project-tag></no-project-tag>" {
+			assert.Contains(t, string(newPom), jib.XMLJibProfile)
+		}
+	}
+
+}
