@@ -26,6 +26,7 @@ import (
 	"time"
 
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
+	"github.com/apache/camel-k/v2/pkg/util/jib"
 
 	"github.com/apache/camel-k/v2/pkg/util/io"
 
@@ -44,25 +45,29 @@ func init() {
 	Quarkus.CommonSteps = []Step{
 		Quarkus.LoadCamelQuarkusCatalog,
 		Quarkus.GenerateQuarkusProject,
-		Quarkus.BuildQuarkusRunner,
+		Quarkus.BuildQuarkusMavenContext,
+		Quarkus.BuildQuarkusMavenProject,
 	}
 }
 
 type quarkusSteps struct {
 	LoadCamelQuarkusCatalog    Step
 	GenerateQuarkusProject     Step
-	BuildQuarkusRunner         Step
+	BuildQuarkusMavenContext   Step
+	BuildQuarkusMavenProject   Step
 	ComputeQuarkusDependencies Step
 	PrepareProjectWithSources  Step
 
 	CommonSteps []Step
 }
 
+//nolint:mnd
 var Quarkus = quarkusSteps{
 	LoadCamelQuarkusCatalog:    NewStep(InitPhase, loadCamelQuarkusCatalog),
 	GenerateQuarkusProject:     NewStep(ProjectGenerationPhase, generateQuarkusProject),
+	BuildQuarkusMavenContext:   NewStep(ProjectGenerationPhase+1, buildMavenContextSettings),
 	PrepareProjectWithSources:  NewStep(ProjectBuildPhase-1, prepareProjectWithSources),
-	BuildQuarkusRunner:         NewStep(ProjectBuildPhase, buildQuarkusRunner),
+	BuildQuarkusMavenProject:   NewStep(ProjectBuildPhase+2, buildMavenProject),
 	ComputeQuarkusDependencies: NewStep(ProjectBuildPhase+1, computeQuarkusDependencies),
 }
 
@@ -101,15 +106,22 @@ func prepareProjectWithSources(ctx *builderContext) error {
 }
 
 func loadCamelQuarkusCatalog(ctx *builderContext) error {
-	catalog, err := camel.LoadCatalog(ctx.C, ctx.Client, ctx.Namespace, ctx.Build.Runtime)
+	runtime := ctx.Build.Runtime.DeepCopy()
+	if runtime.Provider == v1.RuntimeProviderPlainQuarkus {
+		// We need this workaround to load the last existing catalog
+		// TODO: this part will be subject to future refactoring
+		runtime.Version = defaults.DefaultRuntimeVersion
+	}
+
+	catalog, err := camel.LoadCatalog(ctx.C, ctx.Client, ctx.Namespace, *runtime)
 	if err != nil {
 		return err
 	}
 
 	if catalog == nil {
 		return fmt.Errorf("unable to find catalog matching version requirement: runtime=%s, provider=%s",
-			ctx.Build.Runtime.Version,
-			ctx.Build.Runtime.Provider)
+			runtime.Version,
+			runtime.Provider)
 	}
 
 	ctx.Catalog = catalog
@@ -124,7 +136,7 @@ func generateQuarkusProject(ctx *builderContext) error {
 		ctx.Build.Runtime.Metadata["quarkus.version"],
 	)
 	// Add Maven build extensions
-	p.Build.Extensions = ctx.Build.Maven.Extension
+	p.Build.Extensions = &ctx.Build.Maven.Extension
 	// Add Maven repositories
 	p.Repositories = append(p.Repositories, ctx.Build.Maven.Repositories...)
 	p.PluginRepositories = append(p.PluginRepositories, ctx.Build.Maven.Repositories...)
@@ -133,7 +145,13 @@ func generateQuarkusProject(ctx *builderContext) error {
 	return nil
 }
 
-func generateQuarkusProjectCommon(runtimeProvider v1.RuntimeProvider, runtimeVersion string, quarkusPlatformVersion string) maven.Project {
+func generateQuarkusProjectCommon(runtimeProvider v1.RuntimeProvider, runtimeVersion string,
+	quarkusPlatformVersion string) maven.Project {
+	if runtimeProvider == v1.RuntimeProviderPlainQuarkus {
+		// We need this workaround to load the last existing catalog
+		// TODO: this part will be subject to future refactoring
+		quarkusPlatformVersion = runtimeVersion
+	}
 	p := maven.NewProjectWithGAV("org.apache.camel.k.integration", "camel-k-integration", defaults.Version)
 	p.DependencyManagement = &maven.DependencyManagement{Dependencies: make([]maven.Dependency, 0)}
 	p.Dependencies = make([]maven.Dependency, 0)
@@ -191,30 +209,16 @@ func generateQuarkusProjectCommon(runtimeProvider v1.RuntimeProvider, runtimeVer
 		},
 	)
 
+	// Jib publish profile
+	p.AddProfile(jib.JibMavenProfile(jib.JibMavenPluginVersionDefault, jib.JibLayerFilterExtensionMavenVersionDefault))
+
 	return p
 }
 
-func buildQuarkusRunner(ctx *builderContext) error {
-	mc := maven.NewContext(filepath.Join(ctx.Path, "maven"))
-	mc.GlobalSettings = ctx.Maven.GlobalSettings
-	mc.UserSettings = ctx.Maven.UserSettings
-	mc.SettingsSecurity = ctx.Maven.SettingsSecurity
-	mc.LocalRepository = ctx.Build.Maven.LocalRepository
-	mc.AdditionalArguments = ctx.Build.Maven.CLIOptions
+func buildMavenProject(ctx *builderContext) error {
+	mc := newMavenContext(ctx)
 
-	if ctx.Maven.TrustStoreName != "" {
-		mc.ExtraMavenOpts = append(mc.ExtraMavenOpts,
-			"-Djavax.net.ssl.trustStore="+filepath.Join(ctx.Path, ctx.Maven.TrustStoreName),
-			"-Djavax.net.ssl.trustStorePassword="+ctx.Maven.TrustStorePass,
-		)
-	}
-
-	err := BuildQuarkusRunnerCommon(ctx.C, mc, ctx.Maven.Project, ctx.Build.Maven.Properties)
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return BuildQuarkusRunnerCommon(ctx.C, *mc, ctx.Maven.Project, ctx.Build.Maven.Properties)
 }
 
 func BuildQuarkusRunnerCommon(ctx context.Context, mc maven.Context, project maven.Project, applicationProperties map[string]string) error {
@@ -225,9 +229,11 @@ func BuildQuarkusRunnerCommon(ctx context.Context, mc maven.Context, project mav
 	if err := computeApplicationProperties(filepath.Join(resourcesPath, "application.properties"), applicationProperties); err != nil {
 		return err
 	}
+	if err := project.Command(mc).DoPom(ctx); err != nil {
+		return fmt.Errorf("failure while generating pom file: %w", err)
+	}
 	mc.AddArgument("package")
 	mc.AddArgument("-Dmaven.test.skip=true")
-	// Run the Maven goal
 	if err := project.Command(mc).Do(ctx); err != nil {
 		return fmt.Errorf("failure while building project: %w", err)
 	}
@@ -277,15 +283,10 @@ func computeApplicationProperties(appPropertiesPath string, applicationPropertie
 }
 
 func computeQuarkusDependencies(ctx *builderContext) error {
-	mc := maven.NewContext(filepath.Join(ctx.Path, "maven"))
-	mc.GlobalSettings = ctx.Maven.GlobalSettings
-	mc.UserSettings = ctx.Maven.UserSettings
-	mc.SettingsSecurity = ctx.Maven.SettingsSecurity
-	mc.LocalRepository = ctx.Build.Maven.LocalRepository
-	mc.AdditionalArguments = ctx.Build.Maven.CLIOptions
-
+	// Quarkus fast-jar format is split into various sub-directories in quarkus-app
+	quarkusAppDir := filepath.Join(ctx.Path, "maven", "target", "quarkus-app")
 	// Process artifacts list and add it to existing artifacts
-	artifacts, err := ProcessQuarkusTransitiveDependencies(mc)
+	artifacts, err := processQuarkusTransitiveDependencies(quarkusAppDir)
 	if err != nil {
 		return err
 	}
@@ -294,19 +295,16 @@ func computeQuarkusDependencies(ctx *builderContext) error {
 	return nil
 }
 
-func ProcessQuarkusTransitiveDependencies(mc maven.Context) ([]v1.Artifact, error) {
+func processQuarkusTransitiveDependencies(dir string) ([]v1.Artifact, error) {
 	var artifacts []v1.Artifact
 
-	// Quarkus fast-jar format is split into various sub-directories in quarkus-app
-	quarkusAppDir := filepath.Join(mc.Path, "target", "quarkus-app")
-
 	// Discover application dependencies from the Quarkus fast-jar directory tree
-	err := filepath.Walk(quarkusAppDir, func(filePath string, info os.FileInfo, err error) error {
+	err := filepath.Walk(dir, func(filePath string, info os.FileInfo, err error) error {
 		if err != nil {
 			return err
 		}
 
-		fileRelPath := strings.Replace(filePath, quarkusAppDir, "", 1)
+		fileRelPath := strings.Replace(filePath, dir, "", 1)
 
 		if !info.IsDir() {
 			sha1, err := digest.ComputeSHA1(filePath)
