@@ -30,3 +30,20 @@ func artifactIDs(artifacts []v1.Artifact) []string {
 
 	return result
 }
+
+// initializeStatusFrom helps creating a BuildStatus from scratch filling with base and root images.
+func initializeStatusFrom(buildStatus v1.BuildStatus, taskBaseImage string) *v1.BuildStatus {
+	status := v1.BuildStatus{}
+	baseImage := buildStatus.BaseImage
+	if baseImage == "" {
+		baseImage = taskBaseImage
+	}
+	status.BaseImage = baseImage
+	rootImage := buildStatus.RootImage
+	if rootImage == "" {
+		rootImage = taskBaseImage
+	}
+	status.RootImage = rootImage
+
+	return &status
+}
