@@ -29,6 +29,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/resources"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/log"
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
@@ -138,7 +139,9 @@ func (action *createAction) handleNewCatalog(ctx context.Context, platform *v1.I
 	catalog *v1.CamelCatalog, runtimeSpec v1.RuntimeSpec) (*v1.IntegrationPlatform, error) {
 	var camelVersion string
 	if catalog == nil {
-		cat, err := camel.CreateCatalog(ctx, action.client, platform.Namespace, platform, runtimeSpec)
+		cat, err := camel.CreateCatalog(
+			ctx, action.client, platform.Namespace, platform.Status.Build.Maven,
+			platform.Status.Build.GetTimeout().Duration, runtimeSpec, nil)
 		if err != nil {
 			action.L.Error(err, "IntegrationPlatform unable to create Camel catalog",
 				"runtime-version", runtimeSpec.Version, "runtime-provider", runtimeSpec.Provider)
@@ -172,8 +175,9 @@ func installKamelets(ctx context.Context, c client.Client, platform *v1.Integrat
 				v1.IntegrationPlatformConditionKameletCatalogAvailable,
 				corev1.ConditionFalse,
 				"IntegrationPlatformKameletCatalogAvailable",
-				fmt.Sprintf("kamelet catalog %s not available. Error: %s", camelVersion, err),
+				fmt.Sprintf("kamelet catalog %s not available. Error: %v", camelVersion, err),
 			)
+			log.Errorf(err, "A failure happened while loading Kamelet catalog %s", camelVersion)
 		} else {
 			message := fmt.Sprintf("successfully installed Kamelet catalog version %s: success %d Kamelets, failed %d Kamelets",
 				camelVersion, installedKam, erroredKam)
