@@ -29,10 +29,10 @@ import (
 	"time"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -102,7 +102,7 @@ spec:
 }
 
 func TestPrepareKameletsPermissions(t *testing.T) {
-	c, err := test.NewFakeClient()
+	c, err := internal.NewFakeClient()
 	assert.NoError(t, err)
 	err = prepareKameletsPermissions(context.TODO(), c, "camel-k")
 	assert.NoError(t, err)
@@ -115,7 +115,7 @@ func TestPrepareKameletsDirectory(t *testing.T) {
 }
 
 func TestDownloadKameletDependencyAndExtract(t *testing.T) {
-	cli, err := test.NewFakeClient()
+	cli, err := internal.NewFakeClient()
 	assert.NoError(t, err)
 	itp := v1.NewIntegrationPlatform("itp-ns", "my-itp")
 	itp.Status = v1.IntegrationPlatformStatus{
