@@ -53,6 +53,13 @@ var (
 			propSamplerRatio:       "quarkus.opentelemetry.tracer.sampler.ratio",
 			propSamplerParentBased: "quarkus.opentelemetry.tracer.sampler.parent-based",
 		},
+		v1.RuntimeProviderPlainQuarkus: {
+			propEndpoint:           "quarkus.opentelemetry.tracer.exporter.otlp.endpoint",
+			propServiceName:        "quarkus.opentelemetry.tracer.resource-attributes",
+			propSampler:            "quarkus.opentelemetry.tracer.sampler",
+			propSamplerRatio:       "quarkus.opentelemetry.tracer.sampler.ratio",
+			propSamplerParentBased: "quarkus.opentelemetry.tracer.sampler.parent-based",
+		},
 	}
 )
 
@@ -124,7 +131,7 @@ func (t *telemetryTrait) Configure(e *Environment) (bool, *TraitCondition, error
 func (t *telemetryTrait) Apply(e *Environment) error {
 	util.StringSliceUniqueAdd(&e.Integration.Status.Capabilities, v1.CapabilityTelemetry)
 
-	if e.CamelCatalog.CamelCatalogSpec.Runtime.Provider == v1.RuntimeProviderQuarkus {
+	if e.CamelCatalog.CamelCatalogSpec.Runtime.Provider.IsQuarkusBased() {
 		// Hack for camel-k-runtime >= 3.15.0
 		ck315, err := semver.NewVersion("3.15.0")
 		if err != nil {
