@@ -30,6 +30,7 @@ func init() {
 	AddToTraits(newDeploymentTrait)
 	AddToTraits(newEnvironmentTrait)
 	AddToTraits(newGCTrait)
+	AddToTraits(newGitTrait)
 	AddToTraits(newHealthTrait)
 	AddToTraits(NewInitTrait)
 	AddToTraits(newIngressTrait)
@@ -53,7 +54,6 @@ func init() {
 	AddToTraits(newRouteTrait)
 	AddToTraits(newSecurityContextTrait)
 	AddToTraits(newServiceTrait)
-	AddToTraits(newServiceBindingTrait)
 	AddToTraits(NewTelemetryTrait)
 	AddToTraits(newTolerationTrait)
 	// ^^ Declaration order is not important, but let's keep them sorted for debugging.
