@@ -22,24 +22,25 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestCompression(t *testing.T) {
 	source := "this is a script"
 	var compressed bytes.Buffer
 	err := Compress(&compressed, []byte(source))
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	var uncompressed bytes.Buffer
 	err = Uncompress(&uncompressed, compressed.Bytes())
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, source, uncompressed.String())
 }
 
 func TestCompression64(t *testing.T) {
 	source := "this is a script"
 	compressed, err := CompressBase64([]byte(source))
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	uncompressed, err := UncompressBase64(compressed)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, source, string(uncompressed))
 }
