@@ -22,12 +22,13 @@ import (
 
 	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/knative"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	v1 "k8s.io/api/core/v1"
 )
 
 func TestAPIs(t *testing.T) {
 	ref, err := ExtractObjectReference("knative:endpoint/ciao")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs := FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -37,10 +38,10 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?apiVersion=serving.knative.dev/v1")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
-	assert.Equal(t, 1, len(refs))
+	assert.Len(t, refs, 1)
 	assert.Equal(t, v1.ObjectReference{
 		Kind:       "Service",
 		APIVersion: "serving.knative.dev/v1",
@@ -48,10 +49,10 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?apiVersion=serving.knative.dev/v1&kind=Xxx")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
-	assert.Equal(t, 1, len(refs))
+	assert.Len(t, refs, 1)
 	assert.Equal(t, v1.ObjectReference{
 		Kind:       "Xxx",
 		APIVersion: "serving.knative.dev/v1",
@@ -59,10 +60,10 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?apiVersion=yyy&kind=Xxx")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
-	assert.Equal(t, 1, len(refs))
+	assert.Len(t, refs, 1)
 	assert.Equal(t, v1.ObjectReference{
 		Kind:       "Xxx",
 		APIVersion: "yyy",
@@ -70,7 +71,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?kind=Service")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -80,7 +81,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?kind=Channel")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -90,7 +91,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:endpoint/ciao?kind=KafkaChannel")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEndpoint, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -100,7 +101,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:channel/ciao")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeChannel, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -110,7 +111,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:channel/ciao?apiVersion=messaging.knative.dev/v1")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeChannel, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -120,12 +121,12 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:channel/ciao?apiVersion=xxx.knative.dev/v1alpha1")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeChannel, ref)
-	assert.Equal(t, 0, len(refs))
+	assert.Empty(t, refs)
 
 	ref, err = ExtractObjectReference("knative:event/ciao")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEvent, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -135,7 +136,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:event/ciao?apiVersion=xxx")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEvent, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -145,7 +146,7 @@ func TestAPIs(t *testing.T) {
 	}, refs[0])
 
 	ref, err = ExtractObjectReference("knative:event/ciao?name=aaa")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	refs = FillMissingReferenceData(knative.CamelServiceTypeEvent, ref)
 	checkValidRefs(t, refs)
 	assert.Equal(t, v1.ObjectReference{
@@ -158,7 +159,7 @@ func TestAPIs(t *testing.T) {
 func checkValidRefs(t *testing.T, refs []v1.ObjectReference) {
 	t.Helper()
 
-	assert.True(t, len(refs) > 0)
+	assert.Greater(t, len(refs), 0)
 	for _, ref := range refs {
 		assert.NotNil(t, ref.Name)
 		assert.NotNil(t, ref.Kind)
